==> rho-common-facade-1.0.0-sources.jar: cn/smarthse/rho/modules/sys/entity/m/MOnlineMonitorDevice.java <==
package cn.smarthse.rho.modules.sys.entity.m;

import cn.smarthse.core.framework.model.BaseEntity;
import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;

import javax.persistence.Column;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import java.util.Date;


@ApiModel(value = "三同时项目专家信息 对象", description = "医院：三同时项目专家信息")
@EqualsAndHashCode(callSuper = true)
@TableName("m_online_monitor_device")
@Data
public class MOnlineMonitorDevice extends BaseEntity {

    private static final long serialVersionUID = 1L;
    /**
     * Id
     */
    @ApiModelProperty("ID")
    @TableId(value = "id", type = IdType.ASSIGN_ID)
    private Long id;

    @ApiModelProperty("所在医院名称")
    private Long cid;

    @ApiModelProperty("所在医院名称")
    private String companyName;

    @ApiModelProperty("所在行政区划地址")
    private String address;

    @ApiModelProperty("设备类型")
    private Integer deviceType;

    @ApiModelProperty("设备名称")
    private String deviceName;

    @ApiModelProperty("设备编号")
    private String deviceNo;

    @ApiModelProperty("安装位置")
    private String position;

    @ApiModelProperty("所属账号")
    private String belongAccount;

    @ApiModelProperty("设备运行状态，0未运行，1离线，2在线")
    private Integer deviceStatus;

    @ApiModelProperty("状态(0-正常,1-报警,2-离线)")
    private Integer status;

    @ApiModelProperty("最近报警时间")
    private Date latestAlarmDate;

    @ApiModelProperty("阈值")
    private Long threshold;

    @ApiModelProperty("监控视频地址")
    private String videoAddress;

}

==> rho-common-facade-2.0.0-sources.jar: cn/smarthse/rho/modules/sys/entity/m/MOnlineMonitorDevice.java <==
package cn.smarthse.rho.modules.sys.entity.m;

import cn.smarthse.rho.core.framework.model.BaseEntity;
import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import lombok.Data;
import lombok.EqualsAndHashCode;

import java.util.Date;




//@ApiModel(value = "三同时项目专家信息 对象", description = "医院：三同时项目专家信息")
@EqualsAndHashCode(callSuper = true)
@TableName("m_online_monitor_device")
@Data
public class MOnlineMonitorDevice extends BaseEntity {

    private static final long serialVersionUID = 1L;
    /**
     * Id
     */
    //@ApiModelProperty("ID")
    @TableId(value = "id", type = IdType.ASSIGN_ID)
    private Long id;

    //@ApiModelProperty("所在医院名称")
    private Long cid;

    //@ApiModelProperty("所在医院名称")
    private String companyName;

    //@ApiModelProperty("所在行政区划地址")
    private String address;

    //@ApiModelProperty("设备类型")
    private Integer deviceType;

    //@ApiModelProperty("设备名称")
    private String deviceName;

    //@ApiModelProperty("设备编号")
    private String deviceNo;

    //@ApiModelProperty("安装位置")
    private String position;

    //@ApiModelProperty("所属账号")
    private String belongAccount;

    //@ApiModelProperty("设备运行状态，0未运行，1离线，2在线")
    private Integer deviceStatus;

    //@ApiModelProperty("状态(0-正常,1-报警,2-离线)")
    private Integer status;

    //@ApiModelProperty("最近报警时间")
    private Date latestAlarmDate;

    //@ApiModelProperty("阈值")
    private Long threshold;

    //@ApiModelProperty("监控视频地址")
    private String videoAddress;

}
